@@ -85,6 +85,29 @@ extern "C"
         out << footer << std::endl;
     }
 
+    void* SaveTimelineMC(void* lt, const char *filename, const char *header, const char* footer, void *ptr, int exponent, uint64_t startgen) {
+
+        auto lab = reinterpret_cast<apg::lifetree_abstract<uint32_t>*>(lt);
+
+        apg::pattern** patarray = reinterpret_cast<apg::pattern**>(ptr);
+
+        apg::pattern emptypat(lab, "", patarray[0]->getrule());
+
+        std::vector<apg::hypernode<uint32_t> > hnodes;
+
+        uint64_t i = 0;
+        while (patarray[i] != 0) {
+            hnodes.push_back(emptypat.coerce(*(patarray[i])));
+            i += 1;
+        }
+
+        std::ofstream out(filename);
+        lab->write_macrocell_header(out);
+        out << header;
+        lab->write_macrocell_headerless(out, hnodes, emptypat.getrule(), 2, exponent, startgen);
+        out << footer << std::endl;
+    }
+
     void* BooleanPatternImmutable(void* pat1, void* pat2, int op) {
         auto ppat1 = reinterpret_cast<apg::pattern*>(pat1);
         auto ppat2 = reinterpret_cast<apg::pattern*>(pat2);
