@@ -3,7 +3,7 @@ from .lowlevel import *
 from numbers import Integral
 from .crt import chinese_remainder, large_primes
 from .samples import download_synthesis as dsynth
-
+from .registry import register_pattern_callback
 
 def randfill(item, shape):
     '''
@@ -489,7 +489,7 @@ class Pattern(object):
 
 
     def viewer(self, filename=None, width=480, height=480, base64=True,
-                lv_config='#C [[ THEME 6 GRID GRIDMAJOR 0 ]]', autoremove=True):
+                lv_config='#C [[ THEME 6 GRID GRIDMAJOR 0 ]]', autoremove=True, edit=True):
 
         if filename is None:
             filename = self.session.newfloat('viewer') + '.html'
@@ -498,7 +498,32 @@ class Pattern(object):
         header += '<div class="rle"><div style="display:none;"><code id="code2">\n'
         footer = '#C [[ WIDTH %d HEIGHT %d ]]\n' % (width, height)
         footer += '</code></div>\n<canvas width="%d" height="%d" style="margin-left:1px;"></canvas></div>\n' % (width+16, height+16)
-        footer += "<script type='text/javascript' src='http://www.conwaylife.com/js/lv-plugin.js'></script></body>\n"
+        footer += "<script type='text/javascript' src='https://gol.hatsya.co.uk/js/lv-plugin.js'></script>\n"
+
+        if edit:
+            # Generate a unique identifier for the IFrame, so that the Jupyter
+            # notebook knows which LifeViewer has been updated with Ctrl+S.
+            from uuid import uuid4
+            saveid = str(uuid4())
+
+            # Track when the (invisible!) RLE element is changed, and signal
+            # those changes in a message from the IFrame to the notebook. We
+            # can catch these messages in the notebook itself.
+            footer += '''<script>
+var targetNode = document.getElementById('code2');
+var config = { attributes: true, childList: true, subtree: true };
+var callback = function(mutationsList, observer) {
+    console.log("DOM mutated.");
+    parent.postMessage({ rle: targetNode.innerHTML, uuid: "%s" }, "*");
+};
+var observer = new MutationObserver(callback);
+observer.observe(targetNode, config);
+</script>''' % saveid
+
+            # Register this pattern in the registry:
+            register_pattern_callback(saveid, self)
+
+        footer += '</body></html>\n'
 
         self.write_rle(filename, header, lv_config + '\n' + footer)
 
