@@ -473,6 +473,10 @@ b3o$25bo6bobo2b2o$13bobo7bob2o$12b2ob2o6bobo$13bob2o6b2o$2bo14bo$bobo12bo$2ob
 
         self.assertEqual(p57loop.period, 57)
 
+        p57a = p57loop.apgcode
+        self.assertEqual(len(p57a), 3083)
+        self.assertEqual(self.lt.pattern(p57a).period, 57)
+
         p57gun = p57loop.replace(just_eater, with_catalyst, n_phases=57, orientations=['identity', 'rot180'])
 
         self.assertEqual(p57gun.population, 6690)
